This function implements the fence procedure to find the best generalised linear model.
Arguments
- mf
an object of class
glmspecifying the full model.- cstar
the boundary of the fence, typically found through bootstrapping.
- nvmax
the maximum number of variables that will be be considered in the model.
- adaptive
logical. If
TRUEthe boundary of the fence is given by cstar. Otherwise, it the original (non-adaptive) fence is performed where the boundary is \(c^* \hat{\sigma}_{M,\tilde{M}}\).- trace
logical. If
TRUEthe function prints out its progress as it iterates up through the dimensions.- ...
further arguments (currently unused)